@@ -16,10 +16,18 @@ from petisco.domain.errors.empty_value_object_error import EmptyValueObjectError
 from petisco.domain.errors.exceed_length_limit_value_error_error import (
     ExceedLengthLimitValueObjectError,
 )
+from petisco.domain.errors.given_name_is_not_valid_error import GivenNameIsNotValidError
+from petisco.domain.errors.unknown_error import UnknownError
+from petisco.domain.value_objects.integer_value_object import IntegerValueObject
 from petisco.domain.value_objects.name import Name
 from petisco.domain.value_objects.client_id import ClientId
+from petisco.domain.value_objects.string_value_object import (
+    StringValueObject,
+    InvalidStringValueObjectError,
+)
 from petisco.domain.value_objects.user_id import UserId
 from petisco.domain.value_objects.correlation_id import CorrelationId
+from petisco.domain.value_objects.uuid import Uuid, InvalidUuidError
 from petisco.domain.value_objects.value_object import ValueObject
 from petisco.events.publisher.domain.interface_event_publisher import IEventPublisher
 from petisco.events.publisher.infrastructure.not_implemented_event_publisher import (
@@ -56,7 +64,7 @@ from petisco.use_case import use_case_handler
 from petisco.controller.controller_handler import controller_handler
 from petisco.controller.errors.http_error import HttpError
 from petisco.events.event import Event, Events, unique_events
-from petisco.events.event_id import EventId
+from petisco.events.event_id import EventId, InvalidEventIdError
 
 classes = [
     "IService",
@@ -72,6 +80,7 @@ classes = [
     "RoutingKey",
     "Events",
     "EventId",
+    "InvalidEventIdError",
     "unique_events",
     "Singleton",
     "TokenManager",
@@ -84,6 +93,13 @@ classes = [
     "Name",
     "ClientId",
     "UserId",
+    "Uuid",
+    "StringValueObject",
+    "IntegerValueObject",
+    "InvalidUuidError",
+    "InvalidStringValueObjectError",
+    "GivenNameIsNotValidError",
+    "UnknownError",
     "InfoId",
     "AggregateRoot",
     "Petisco",
